"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
// Import css
require("../../../css/tour.css");
const XIcon_1 = __importDefault(require("../icons/XIcon"));
// Location to display the TourStep popup
var TourPopupLocation;
(function (TourPopupLocation) {
    TourPopupLocation["BOTTOM_LEFT"] = "bottom_left";
    TourPopupLocation["BOTTOM_RIGHT"] = "bottom-right";
})(TourPopupLocation || (TourPopupLocation = {}));
const steps = [
    {
        overlay: false,
        stepHeader: 'Analyses in the Sidebar',
        stepHeaderBackgroundColor: '#BCDFBC',
        stepText: react_1.default.createElement("div", null,
            " With Mito's sidebars, it's easy to perform powerful analyses, like creating pivot tables, merging dataframes, and filtering your data. ",
            react_1.default.createElement("b", null, " Click on the pivot table button to get started"),
            ". "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: false,
    },
    {
        overlay: false,
        stepHeader: 'Create a Pivot Table',
        stepHeaderBackgroundColor: '#DDA1A1',
        stepText: react_1.default.createElement("div", null,
            " In the open sidebar, ",
            react_1.default.createElement("b", null, "select a row and value "),
            " to create your pivot table. Pivot tables group your data by the selected rows and columns, and then aggregate the values. "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        overlay: false,
        stepHeader: 'That was easy!',
        stepHeaderBackgroundColor: '#79C2F8',
        stepText: react_1.default.createElement("div", null,
            "Each time you make an edit in Mito, the equivalent pandas code is generated below the Mito sheet. ",
            react_1.default.createElement("b", null, "Checkout the pivot table code below"),
            ". We just saved our first trip to stack overflow :) "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        overlay: false,
        stepHeader: 'See the full tutorial',
        stepHeaderBackgroundColor: '#FFDAAE',
        stepText: react_1.default.createElement("div", null,
            "Clean and analyze your data by writing spreadsheet formulas, visualizing your data, and adding filters. Find a more detailed tutorial ",
            react_1.default.createElement("a", { href: "https://docs.trymito.io/getting-started/tutorial", target: "_blank", rel: "noreferrer", style: { color: '#0081DE' } }, "here"),
            "."),
        location: TourPopupLocation.BOTTOM_RIGHT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Close"),
        displayBackButton: true
    }
];
const Tour = (props) => {
    const [stepNumber, setStepNumber] = react_1.useState(0);
    // Watch for step changes and update the highlighting of the pivot table button.
    react_1.useEffect(() => {
        if (stepNumber === 0) {
            props.setHighlightPivotTableButton(true);
            void props.mitoAPI.sendLogMessage('begin_tour', {});
        }
        else {
            props.setHighlightPivotTableButton(false);
        }
    }, [stepNumber]);
    // Go to stepNumber if it exists, otherwise close the tour
    const goToStep = (newStepNumber) => {
        // Log switching steps
        void props.mitoAPI.sendLogMessage('switched_tour_step', {
            'old_tour_step': stepNumber,
            'new_tour_step': newStepNumber
        });
        if (newStepNumber < steps.length) {
            setStepNumber(newStepNumber);
        }
        else {
            void closeTour('pivot_tour');
        }
    };
    const closeTour = (tourName) => __awaiter(void 0, void 0, void 0, function* () {
        // Log closing the tour
        if (stepNumber >= steps.length - 1) {
            void props.mitoAPI.sendLogMessage('finished_tour');
        }
        else {
            void props.mitoAPI.sendLogMessage('closed_tour_early');
        }
        // Make sure that the pivot button is not stuck in pulsing mode. 
        props.setHighlightPivotTableButton(false);
        // Send the closeTour message to the backend
        yield props.mitoAPI.sendCloseTour(tourName);
    });
    const progressBarDots = [];
    steps.forEach((step, index) => {
        // Determine if the dot should be small or large
        const diameterClassName = index === stepNumber ? 'tour-progress-bar-dot  large-dot' : 'tour-progress-bar-dot  small-dot';
        progressBarDots.push((react_1.default.createElement("div", { className: diameterClassName, onClick: () => goToStep(index) })));
    });
    // Get the location to display the tour as a className
    const tourContainerLocation = steps[stepNumber].location === TourPopupLocation.BOTTOM_LEFT ?
        'tour-container tour-container-bottom-left' :
        'tour-container tour-container-bottom-right';
    // If we're at a valid step number
    return (react_1.default.createElement("div", { className: tourContainerLocation, key: stepNumber },
        react_1.default.createElement("div", { className: 'tour-header-container', style: { backgroundColor: steps[stepNumber].stepHeaderBackgroundColor } },
            steps[stepNumber].stepHeader,
            react_1.default.createElement("div", { className: 'tour-header-close-button', onClick: () => closeTour('pivot_tour') },
                react_1.default.createElement(XIcon_1.default, null))),
        react_1.default.createElement("div", { className: 'tour-step-text-container' }, steps[stepNumber].stepText),
        react_1.default.createElement("div", { className: 'tour-button-container' },
            steps[stepNumber].displayBackButton &&
                react_1.default.createElement("div", { className: 'tour-close-button', onClick: () => goToStep(stepNumber - 1) }, "Back"),
            react_1.default.createElement("div", { className: 'tour-continue-button', onClick: () => goToStep(stepNumber + 1) }, steps[stepNumber].advanceButtonText)),
        react_1.default.createElement("div", { className: 'tour-progress-bar-container' }, progressBarDots)));
};
exports.default = Tour;
//# sourceMappingURL=Tour.js.map